/*
    kzsync

    Version alpha

    Copyright (c) 2002 Luc Saillard <luc@saillard.org>

    This program is free software; you can redistribute it and/or
    modify it under the terms of version 2 of the GNU General Public
    License as published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#include <kapplication.h>
#include <kabc/stdaddressbook.h>
#include <kabc/distributionlist.h>
#include <kcmdlineargs.h>
#include <kuniqueapplication.h>
#include <klocale.h>

#include <stdio.h>
#include <iostream>

#include "zaurus.h"

#include <qfile.h>

using namespace std;

//static void xml_input(KABC::AddressBook *ab);
static void xml_output(KABC::AddressBook *ab);
static void save_data_xml(QTextStream &stream, const QString &key, const QString &value);
static void save_phonenumber_xml(QTextStream &stream, const QString &key, const KABC::PhoneNumber &phone);
static void save_address_xml(QTextStream &stream, const QString &prefix, const KABC::Address &address);
static QString escapeString( const QString& plain );


int main(int argc, char **argv)
{
    const char *version = "0.1alpha";
    const char *description = "Simple application to synchronize Korganiser and the Zaurus PDA";
    KCmdLineOptions options[] =
     {
       //        { "+command", "[url1,url2 ,...]", 0 },
	{ 0, 0, 0 }
     };

    KCmdLineArgs::init(argc, argv, "kzsync", description, version );
    KCmdLineArgs::addCmdLineOptions( options );
    KApplication app(false,false);
    
    KABC::AddressBook *ab = KABC::StdAddressBook::self();

    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
    args->clear(); // Free up some memory.

//    ab->dump();
    
    Zaurus zz;
    zz.getAddressBook();

    /*
       xml_input(ab);
       xml_output(ab);
       */

    return 0;
}

static void xml_output(KABC::AddressBook *ab)
{
  KABC::AddressBook::Iterator it;
  int count;

  QFile file( "addressbook.xml" );
  if (!file.open(IO_WriteOnly))
    return;
  QTextStream stream( &file );

  stream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?><!DOCTYPE Addressbook>\n" ;
  stream << "<Addressbook>\n";
  stream << " <Groups>\n";
  stream << " </Groups>\n";
  stream << " <Contacts>\n";

  for (count=0,it=ab->begin(); it != ab->end(); it++, count++)
   {
     KABC::Addressee entry=*it;

     stream << "  <Contact ";
     save_data_xml(stream,"FirstName",entry.givenName());
     save_data_xml(stream,"LastName",entry.familyName());
     save_data_xml(stream,"MiddleName",entry.additionalName());
     save_data_xml(stream,"FileAs",entry.formattedName());
     save_data_xml(stream,"JobTitle",entry.title());
     save_data_xml(stream,"Company",entry.organization());

     save_phonenumber_xml(stream,"BusinessPhone",entry.phoneNumber(KABC::PhoneNumber::Work));
     save_phonenumber_xml(stream,"BusinessFax",entry.phoneNumber(KABC::PhoneNumber::Work|KABC::PhoneNumber::Fax));
     save_phonenumber_xml(stream,"BusinessMobile",entry.phoneNumber(KABC::PhoneNumber::Work|KABC::PhoneNumber::Cell));
     save_phonenumber_xml(stream,"HomePhone",entry.phoneNumber(KABC::PhoneNumber::Home));
     save_phonenumber_xml(stream,"HomeFax",entry.phoneNumber(KABC::PhoneNumber::Home|KABC::PhoneNumber::Fax));
     save_phonenumber_xml(stream,"HomeMobile",entry.phoneNumber(KABC::PhoneNumber::Home|KABC::PhoneNumber::Cell));

     save_address_xml(stream,"Business",entry.address(KABC::Address::Work));
     save_address_xml(stream,"Home",entry.address(KABC::Address::Home));

     save_data_xml(stream,"HomeWebPage",entry.url().url());
     if (!entry.birthday().isNull())
       save_data_xml(stream,"Birthday",entry.birthday().date().toString(Qt::ISODate));
     //save_data_xml(stream,"Anniversary",entry.anniversary().toString());
     save_data_xml(stream,"Nickname",entry.nickName());
     save_data_xml(stream,"Uid",entry.uid());
     save_data_xml(stream,"Note",entry.note());
     
     stream << " />\n";
   }

  stream << " </Contacts>\n";
  stream << "</Addressbook>" << endl;

  file.close();
}


static void save_data_xml(QTextStream &stream, const QString &key, const QString &value)
{   
  if (value && !value.isEmpty())
    stream << key << "=\"" << escapeString(value).utf8() << "\" ";
}

static void save_phonenumber_xml(QTextStream &stream, const QString &key, const KABC::PhoneNumber &phone)
{   
  if (!phone.number().isEmpty())
    stream << key << "=\"" << phone.number().utf8() << "\" ";
}

static void save_address_xml(QTextStream &stream, const QString &prefix, const KABC::Address &address)
{   
  if (!address.isEmpty())
  {
      stream << prefix << "Street=\"" << escapeString(address.street()).utf8() << "\" ";
      stream << prefix << "City=\"" << escapeString(address.locality()).utf8() << "\" ";
      stream << prefix << "State=\"" << escapeString(address.region()).utf8() << "\" ";
      stream << prefix << "Country=\"" << escapeString(address.country()).utf8() << "\" ";
      stream << prefix << "Zip=\"" << escapeString(address.postalCode()).utf8() << "\" ";
  }
}
static QString escapeString( const QString& plain )
{
  QString tmp(plain);

  int pos = tmp.length();
  const QChar *uc = plain.unicode();
  while ( pos-- ) {
     unsigned char ch = uc[pos].latin1();
     if ( ch == '&' )
       tmp.replace( pos, 1, "&amp;" );
     else if ( ch == '<' )
       tmp.replace( pos, 1, "&lt;" );
     else if ( ch == '>' )
       tmp.replace( pos, 1, "&gt;" );
     else if ( ch == '\"' )
       tmp.replace( pos, 1, "&quot;" );
  }
  return tmp;
}


