/*
    Class to parse the XML addressebook use by the Zaurus (or any Qtopia
    application)

    Version alpha

    Copyright (c) 2002 Luc Saillard <luc@saillard.org>

    This program is free software; you can redistribute it and/or
    modify it under the terms of version 2 of the GNU General Public
    License as published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#include "zaurusparser.h"

#include <stdio.h>
#include <qstring.h>

using namespace KABC;

void ZaurusAddressbookParser::setAddressBook(KABC::AddressBook *ab)
{
  book=ab;
}

bool ZaurusAddressbookParser::startDocument()
{
  return TRUE;
}


static void insertAddr(Addressee &addr, const QString &prefix, const QXmlAttributes &atts)
{
  Address address;

  if (prefix == "Home")
    address.setType(Address::Home);
  else if (prefix == "Business")
    address.setType(Address::Work);
  else
    address.setType(Address::Dom);

  address.setStreet(atts.value(prefix + "Street"));
  address.setLocality(atts.value(prefix + "City"));
  address.setRegion(atts.value(prefix + "State"));
  address.setCountry(atts.value(prefix + "Country"));
  address.setPostalCode(atts.value(prefix + "Zip"));

  addr.insertAddress(address);
}  

bool ZaurusAddressbookParser::startElement(
    const QString &,
    const QString &, 
    const QString& qName, 
    const QXmlAttributes& atts)
{

  if (qName == "Contact")
   {
     QString str;
     Addressee addr;

     addr.setGivenName(QString::fromUtf8(atts.value("FirstName")));
     addr.setFamilyName(atts.value("LastName"));
     addr.setAdditionalName(atts.value("MiddleName"));
     addr.setFormattedName(atts.value("FileAs"));
     addr.setTitle(atts.value("JobTitle"));
     addr.setOrganization(atts.value("Company"));

     addr.insertPhoneNumber(PhoneNumber(atts.value("BusinessPhone"),PhoneNumber::Work));
     addr.insertPhoneNumber(PhoneNumber(atts.value("BusinessFax"),PhoneNumber::Work|PhoneNumber::Fax));
     addr.insertPhoneNumber(PhoneNumber(atts.value("BusinessMobile"),PhoneNumber::Work|PhoneNumber::Cell));

     addr.insertPhoneNumber(PhoneNumber(atts.value("HomePhone"),PhoneNumber::Home));
     addr.insertPhoneNumber(PhoneNumber(atts.value("HomeFax"),PhoneNumber::Home|PhoneNumber::Fax));
     addr.insertPhoneNumber(PhoneNumber(atts.value("HomeMobile"),PhoneNumber::Home|PhoneNumber::Cell));

     insertAddr(addr,"Business",atts);
     insertAddr(addr,"Home",atts);

     addr.setUrl(KURL(atts.value("HomeWebPage")));
     addr.setBirthday(QDateTime(QDate::fromString(atts.value("Birthday"),Qt::ISODate)));
     addr.setNickName(atts.value("Nickname"));
     addr.setUid(atts.value("Uid"));
     addr.setNote(atts.value("Note"));
     
     book->insertAddressee(addr);

     //printf( "%s[%s]%s\n", (const char*)indent,(const char*)qName,(const char *)str);
     
   }

  return TRUE;
}

bool ZaurusAddressbookParser::endElement( const QString&, const QString&, const QString& )
{
  return TRUE;
}

